/*
 * precompile.h
 *
 * OPAL application source file for EXternal RTP demonstration for OPAL
 *
 * Copyright (c) 2011 Vox Lucida Pty. Ltd.
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is Open Phone Abstraction Library.
 *
 * The Initial Developer of the Original Code is Equivalence Pty. Ltd.
 *
 * Contributor(s): ______________________________________.
 *
 * $Revision: 28641 $
 * $Author: rjongbloed $
 * $Date: 2012-12-04 07:37:57 +0000 (Tue, 04 Dec 2012) $
 */

#include <ptlib.h>
#include <opal/console_mgr.h>
#include <ep/localep.h>
#include <sip/sipep.h>
#include <h323/h323ep.h>


// End of File ///////////////////////////////////////////////////////////////
